import * as dsApi from "@/api/ds";
import {deepCopy} from "@/utils";

const useSystemStore = defineStore('system', () => {
  const state = reactive({
    tableCategoryList: [],
    tableCategoryTree: [],
    tableCategoryParents: [],
  })
  const getTableCategory = (dsId) => {
    return new Promise((resolve, reject) => {
      dsApi.categoryList({datasourceId: dsId}).then(res => {
        // 设置平铺列表
        state.tableCategoryList = res.data || []
        // 设置分类树
        let parents = state.tableCategoryList.filter(i => !i.parentId).sort((b, a) => b.orderIndex - a.orderIndex)
        parents.forEach(p => {
          let children = state.tableCategoryList.filter(i => i.parentId === p.id)
          if (children) {
            p.children = children.sort((b, a) => b.orderIndex - a.orderIndex)
            children.forEach(pp => {
              let children2 = state.tableCategoryList.filter(i => i.parentId === pp.id)
              if (children2) pp.children = children2.sort((b, a) => b.orderIndex - a.orderIndex)
            })
          }
        })
        state.tableCategoryTree = parents
        // 设置父级分类树
        let categoryList = deepCopy(state.tableCategoryList)
        categoryList.forEach(i => delete i.children)
        let parents2 = categoryList.filter(i => !i.parentId).sort((b, a) => b.orderIndex - a.orderIndex)
        parents2.forEach(p => {
          let children = categoryList.filter(i => i.parentId === p.id)
          if (children) p.children = children.sort((b, a) => b.orderIndex - a.orderIndex)
        })
        parents2.unshift({categoryName: '顶级分类', id: 0})
        state.tableCategoryParents = parents2
        resolve()
      })
    })
  }
  const getTableCategorySearched = key => {
    let categoryTree2 = deepCopy(state.tableCategoryTree)
    let res = [
      {categoryName: '全部分类', id: 0, parentId: 0},
    ]
    if (!key) {
      return [...res, ...categoryTree2]
    } else {
      let tableCategoryList = deepCopy(state.tableCategoryList)
      let searched = tableCategoryList.filter(i => i.categoryName.includes(key))
      searched.forEach(i => delete i.children)
      return [...res, ...searched]
    }
  }
  return {
    state,
    getTableCategory,
    getTableCategorySearched,
  }
})

export default useSystemStore